@@ -21,6 +21,10 @@ class TestFormats(unittest.TestCase):
     def test__some_method_single_underscore_as_suffix(self):
         assert SomeClass().some_method(None) is None
 
+    def test_with_custom_message(self):
+        """Shows custom message from docstring summary"""
+        assert SomeClass().some_method(None) is None
+
 
 if __name__ == '__main__':
     unittest.main()
